#!/bin/bash
#
# seq.sh - Emulao do comando seq em Bash, por Aurlio M. Jargas
#
# O comando seq recebe dois nmeros e mostra na sada padro todos os
# nmeros existentes entre eles, numa seqncia pronta para ser usada
# pelo comando 'FOR'. Caso omitido o nmero inicial,  utilizado o 1.
#
#         Exemplo1            Exemplo2             Exemplo3
#
#        $ seq 5 10          $ seq 10 5           $ seq 5
#        5                   10                   1
#        6                   9                    2
#        7                   8                    3
#        8                   7                    4
#        9                   6                    5
#        10                  5
#    
# Uso em scripts: for i in `seq 5 10`; do comandos ; done
#    

### Inicializao das variveis
o=+           # Operao a ser feita. Pode ser + ou -
a=1           # Valor padro de incio da contagem
z=${1:-1}     # Valor do final da contagem recebido em $1 (padro  1)

# A varivel 'a'  o nmero de incio e a varivel 'z'  o final.
#
# O cdigo acima serve para quando o usurio passar apenas um valor na
# linha de comando, que seria o valor do *final* da contagem. Por isso
# a=1 e z=$1.
#
# Caso o programa seja chamado sem parmetros, 'z' tambm  definido
# como 1. Como a=1 e z=1, o programa retorna apenas o nmero 1.


[ "$2" ] && {
	
	# Foram passados 2 parmetros, o $1  o incio e o $2  o fim.
	a=$1
	z=$2
}


###
# Se o nmero de incio ($a) for maior que o nmero de final ($z),
# faremos uma contagem regressiva, por isso a operao  definida
# como subtrao.
#
[ $a -gt $z ] && o=-


###
# Loop da contagem (progressiva ou regressiva)
#
# A cada volta, adiciona ou subtrai 1 do valor inicial,
# at que ele se iguale ao final.
#
# O eval executa o resultado da expanso de variveis.
# Supondo o='+' e a=3, o eval executar o comando a=$((3+1)).
#
while [ $a -ne $z ]; do
	echo $a                # mostra a contagem atual
	eval "a=\$((a$o 1))"   # efetua a operao (+1 ou -1)
done

echo $a  	               # mostra o ltimo nmero
